@@ -100,6 +100,9 @@ class Board:
     def GetLabels(self):
         return self.GetData("/labels")
 
+    def GetCustomFields(self):
+        return self.GetData("/customFields")
+
     def GetListByName(self, ListName):
         Lists = self.GetLists()
         for ListObject in Lists:
@@ -137,6 +140,16 @@ class Board:
                 return Label(self.__AUTH, LabelObject["id"])
         return None
 
+    def GetCustomFieldByName(self, CustomFieldName):
+        CustomFields = self.GetCustomFields()
+        for CustomFieldObject in CustomFields:
+            if CustomFieldObject["name"] == CustomFieldName:
+                return CustomField(self.__AUTH, CustomFieldObject["id"])
+        return None
+
+    def GetCustomFieldById(self, CustomFieldId):
+        return Label(self.__AUTH, CustomFieldId)
+
     def SetName(self, Name):
         self.SetProperty("name", Name)
 
@@ -244,6 +257,17 @@ class Card:
     def GetLabels(self):
         return self.GetData()["labels"]
 
+    def GetCustomFieldItems(self):
+        return self.GetData("/customFieldItems")
+
+    def GetCustomFieldItemIdByName(self, CustomFieldName):
+        CustomFields = self.GetCustomFieldItems()
+        for CustomFieldObject in CustomFields:
+            TempCustomField = CustomField(self.__AUTH, CustomFieldObject["idCustomField"])
+            if TempCustomField.GetName() == CustomFieldName:
+                return CustomFieldObject["id"]
+        return None
+
     def IsArchived(self):
         return self.GetData()["closed"]
 
@@ -267,6 +291,10 @@ class Card:
         URL = "https://api.trello.com/1/cards/" + self.GetId() + "/idLabels/" + Label.GetId() + self.__AUTH
         requests.request("DELETE", URL)
 
+    def UpdateCustomFieldItem(self, CustomFieldObject, Value):
+        URL = "https://api.trello.com/1/cards/" + self.GetId() + "/customField/" + CustomFieldObject.GetId() + "/item" + self.__AUTH
+        requests.request("PUT", URL, headers=Headers, data=Value)
+
     def Comment(self, Comment):
         URL = "https://api.trello.com/1/cards/" + self.GetId() + "/actions/comments" + self.__AUTH
         Query = {
@@ -322,4 +350,76 @@ class Label:
         requests.request("DELETE", URL)
 
     def ClassName(self):
-        return "Label"
\ No newline at end of file
+        return "Label"
+
+class CustomField:
+    def __init__(self, Auth, CustomFieldId):
+        self.__AUTH = Auth
+        self.ID = CustomFieldId
+
+    def GetId(self):
+        return self.ID
+
+    def GetData(self, Argument=""):
+        URL = "https://api.trello.com/1/customFields/" + self.GetId() + Argument + self.__AUTH
+        Response = requests.request("GET", URL)
+        Result = json.loads(Response.text)
+        return Result
+
+    def SetProperty(self, Property, Value):
+        URL = "https://api.trello.com/1/customFields/" + self.GetId() + "/" + Property + self.__AUTH + "&value=" + Value
+        requests.request("PUT", URL)
+
+    def GetName(self):
+        return self.GetData()["name"]
+
+    def GetCustomFieldOptions(self):
+        return self.GetData("/options")
+
+    def GetCustomFieldOptionByName(self, CustomFieldOptionName):
+        Options = self.GetCustomFieldOptions()
+        for Option in Options:
+            if Option["value"]["text"] == CustomFieldOptionName:
+                return CustomFieldOption(self.__AUTH, self, Option["_id"])
+        return None
+
+    def SetName(self, CustomFieldName):
+        self.SetProperty("name", CustomFieldName)
+
+    def Delete(self):
+        URL = "https://api.trello.com/1/customFields/" + self.GetId() + self.__AUTH
+        requests.request("DELETE", URL)
+
+    def ClassName(self):
+        return "CustomField"
+
+class CustomFieldOption:
+    def __init__(self, Auth, CustomFieldObject, CustomFieldOptionId):
+        self.__AUTH = Auth
+        self.ID = CustomFieldOptionId
+        self.CustomField = CustomFieldObject
+
+    def GetId(self):
+        return self.ID
+
+    def GetCustomField(self):
+        return self.CustomField
+
+    def GetData(self, Argument=""):
+        URL = "https://api.trello.com/1/customFields/" + self.GetCustomField().GetId() + "/options/" + self.GetId() + Argument + self.__AUTH
+        Response = requests.request("GET", URL)
+        Result = json.loads(Response.text)
+        return Result
+
+    def GetName(self):
+        return self.GetData()["value"]["text"]
+
+    def GetColor(self):
+        return self.GetData()["color"]
+
+    def Delete(self):
+        URL = "https://api.trello.com/1/customFields/" + self.GetCustomField().GetId() + "/options/" + self.GetId() + self.__AUTH
+        requests.request("DELETE", URL)
+
+    def ClassName(self):
+        return "CustomFieldOption"
\ No newline at end of file
